/*
 * Copyright 2004 by Kappich+Kniß Systemberatung, Aachen
 * Copyright 2007-2018 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.dav.daf.
 *
 * de.bsvrz.dav.daf is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.dav.daf is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with de.bsvrz.dav.daf; If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.dav.daf.communication.dataRepresentation.datavalue;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

/**
 * Diese Klasse stellt die Attribute und Funktionalitäten des Datentyps double zur Verfügung.
 *
 * @author Kappich Systemberatung
 * @version $Revision$
 */
public class DoubleAttribute extends DataValue {

	/** Der Doublewert */
	private double _double;

	/** Erzeugt ein neues Objekt ohne Parameter. Die Parameter werden zu einem Späteren Zeitpunkt über die read-Methode eingelesen. */
	public DoubleAttribute() {
		_type = DOUBLE_TYPE;
	}

	/**
	 * Erzeugt ein neues Objekt mit den gegebenen Parametern.
	 *
	 * @param _d double Wert
	 */
	public DoubleAttribute(double _d) {
		_type = DOUBLE_TYPE;
		_double = _d;
	}


	@Override
	public final Object getValue() {
		return _double;
	}


	@Override
	public final DataValue cloneObject() {
		return new DoubleAttribute(_double);
	}


	@Override
	public final String parseToString() {
		return "Double: " + _double + "\n";
	}


	@Override
	public final void write(DataOutputStream out) throws IOException {
		out.writeDouble(_double);
	}

	@Override
	public final void read(DataInputStream in) throws IOException {
		_double = in.readDouble();
	}

	@Override
	public boolean equals(final Object o) {
		if(this == o) return true;
		if(o == null || getClass() != o.getClass()) return false;

		final DoubleAttribute that = (DoubleAttribute) o;

		return Double.compare(that._double, _double) == 0;
	}

	@Override
	public int hashCode() {
		final long temp = Double.doubleToLongBits(_double);
		return (int) (temp ^ (temp >>> 32));
	}
}
